import _import from "./lib/_import";
/**
 *  处理菜单
 * @param menus 菜单对象
 * @param result
 */
export function handleMenus(menus, result) {
  for (let item of menus) {
    //如果是叶子节点，则直接添加到页面菜单中
    if (item.leaf) {
      result.push(item);
    } else if (item.children) {
      //如果含有子节点，则递归添加子菜单
      handleMenus(item.children, result);
    }
  }
}

/**
 * 组装框架Frame项目
 * @param info
 * @returns {Promise<Int32Array | * | Uint32Array | T[] | Int8Array | Float64Array>}
 */
export  async function assembleFrame(frameInfo,_router,_store) {
  //  导入框架项目
  const frame = await _import(frameInfo.name, frameInfo.module, frameInfo.host,frameInfo.version);
  // 框架项目路由注册
  _router.addRoutes(frame.routerStatic);
  // 框架项目Store注册
  for (let storeName in frame.store){
    _store.registerModule(storeName, frame.store[storeName]);
  }
  // 嵌套路由 / 默认两级路由
  return frame.routerStatic.filter(item => item.path == "/");
}
/**
 * 说明：
 * <p><>
 * 组装模块程序
 * @param menus
 * @param childRouter
 * @returns {Promise<void>}
 */
export async function assembleApps(menus, childRouter,_router,_store) {
  //主框架以'/'作为入口的子路由页面
  let pages = childRouter[0].children;
  // 尝试获取模块 / 异步获取
  for (let app of menus)
    if (app.isplugin) {
      _import( app.app,app.module, app.host,app.version)
        .then(appInfo => {
          console.log('@/apps/' + app.module + '/' + app.app + '/plugin.js');
          // 需要生成路由的菜单
          let menusRouter = [];
          //菜单处理
          if(app.children){
            handleMenus(app.children, menusRouter);
          }else{
            menusRouter.push(app);
          }
          // 动态注册模块的路由(包括子应用配置的动态路由和静态路由)
          childRouter[0].children = appInfo
            .router(menusRouter, app.app)
            .concat(appInfo.routerStatic);
          //将子应用中的子路由信息(静态和动态路由两部分)，添加到页面集合中
          pages.push(...childRouter[0].children);
          console.error(pages);
          //将子应用的路由添加到核心路由中
          _router.addRoutes(childRouter);
          // 动态注册子应用的Store
          for (let storeName in appInfo.store) {
            _store.registerModule(storeName, appInfo.store[storeName]);
          }
        })
        .catch(err => {
          console.error('==========================');
          console.error('动态添加子应用'+app.app+'模块出错');
          console.error('==========================');
        });
      if (app.children) {
        //如果含有子节点，则递归添加子菜单
        assembleApps(app.children, childRouter,_router,_store)
      }
    }
  // 储存路由表
  _store.commit("SET_PAGES", pages);

}

/**
 * 加载框架信息和应用模块信息
 * @param frameInfo 框架模块信息
 * @param apps 应用信息
 * @returns {Promise<void>}
 */
export  async function initApp(frameInfo,apps,_router,_store){
  // 组装基座并获取基座嵌套路由
  let childRouter = await assembleFrame(frameInfo,_router,_store);
  // 组装模块
  assembleApps(apps, childRouter,_router,_store);
  console.log(childRouter);
}

/**
 * 根据菜单构建对应的路由
 * @param menusRouter 菜单路由
 * @param appName 应用名称
 * @returns {Array}
 */
export  function autoMenusRouter(menusRouter, appName) {
  let router = [];
  let appPath='apps'
  // 动态路由
  for (let item of menusRouter)
    if(item.module.length>0){
      router.push({
        name: item.module +"-"+ item.app + item.page,
        path: "/"+item.module +"/"+ item.app + item.page,
        component: () =>
          import(
          `@apps/${item.module}/${item.app}${item.page}`
            ),
        meta: {
          appName: item.module +"-"+ item.app + item.page,
          name: item.name,
          resource: item.resource ? item.resource : []
        }
      });
    }else{
      router.push({
        name: item.module +"-"+ item.app + item.page,
        path: "/"+ item.app + item.page,
        component: () =>
          import(
          `@apps/${item.app}${item.page}`
            ),
        meta: {
          appName: item.module +"-"+ item.app + item.page,
          name: item.name,
          resource: item.resource ? item.resource : []
        }
      });
    }
  return router;
}
